@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Any, Dict, List, Union
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
 
@@ -175,7 +175,7 @@ _RequiredAddAttributesActivityTypeDef = TypedDict(
     "_RequiredAddAttributesActivityTypeDef",
     {
         "name": str,
-        "attributes": Dict[str, str],
+        "attributes": Mapping[str, str],
     },
 )
 _OptionalAddAttributesActivityTypeDef = TypedDict(
@@ -207,7 +207,7 @@ BatchPutMessageRequestRequestTypeDef = TypedDict(
     "BatchPutMessageRequestRequestTypeDef",
     {
         "channelName": str,
-        "messages": List["MessageTypeDef"],
+        "messages": Sequence["MessageTypeDef"],
     },
 )
 
@@ -250,7 +250,7 @@ class ChannelActivityTypeDef(_RequiredChannelActivityTypeDef, _OptionalChannelAc
 ChannelMessagesTypeDef = TypedDict(
     "ChannelMessagesTypeDef",
     {
-        "s3Paths": List[str],
+        "s3Paths": Sequence[str],
     },
     total=False,
 )
@@ -275,7 +275,7 @@ ChannelStorageSummaryTypeDef = TypedDict(
 ChannelStorageTypeDef = TypedDict(
     "ChannelStorageTypeDef",
     {
-        "serviceManagedS3": Dict[str, Any],
+        "serviceManagedS3": Mapping[str, Any],
         "customerManagedS3": "CustomerManagedChannelS3StorageTypeDef",
     },
     total=False,
@@ -328,7 +328,7 @@ _RequiredContainerDatasetActionTypeDef = TypedDict(
 _OptionalContainerDatasetActionTypeDef = TypedDict(
     "_OptionalContainerDatasetActionTypeDef",
     {
-        "variables": List["VariableTypeDef"],
+        "variables": Sequence["VariableTypeDef"],
     },
     total=False,
 )
@@ -351,7 +351,7 @@ _OptionalCreateChannelRequestRequestTypeDef = TypedDict(
     {
         "channelStorage": "ChannelStorageTypeDef",
         "retentionPeriod": "RetentionPeriodTypeDef",
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -407,18 +407,18 @@ _RequiredCreateDatasetRequestRequestTypeDef = TypedDict(
     "_RequiredCreateDatasetRequestRequestTypeDef",
     {
         "datasetName": str,
-        "actions": List["DatasetActionTypeDef"],
+        "actions": Sequence["DatasetActionTypeDef"],
     },
 )
 _OptionalCreateDatasetRequestRequestTypeDef = TypedDict(
     "_OptionalCreateDatasetRequestRequestTypeDef",
     {
-        "triggers": List["DatasetTriggerTypeDef"],
-        "contentDeliveryRules": List["DatasetContentDeliveryRuleTypeDef"],
+        "triggers": Sequence["DatasetTriggerTypeDef"],
+        "contentDeliveryRules": Sequence["DatasetContentDeliveryRuleTypeDef"],
         "retentionPeriod": "RetentionPeriodTypeDef",
         "versioningConfiguration": "VersioningConfigurationTypeDef",
-        "tags": List["TagTypeDef"],
-        "lateDataRules": List["LateDataRuleTypeDef"],
+        "tags": Sequence["TagTypeDef"],
+        "lateDataRules": Sequence["LateDataRuleTypeDef"],
     },
     total=False,
 )
@@ -451,7 +451,7 @@ _OptionalCreateDatastoreRequestRequestTypeDef = TypedDict(
     {
         "datastoreStorage": "DatastoreStorageTypeDef",
         "retentionPeriod": "RetentionPeriodTypeDef",
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
         "fileFormatConfiguration": "FileFormatConfigurationTypeDef",
         "datastorePartitions": "DatastorePartitionsTypeDef",
     },
@@ -479,13 +479,13 @@ _RequiredCreatePipelineRequestRequestTypeDef = TypedDict(
     "_RequiredCreatePipelineRequestRequestTypeDef",
     {
         "pipelineName": str,
-        "pipelineActivities": List["PipelineActivityTypeDef"],
+        "pipelineActivities": Sequence["PipelineActivityTypeDef"],
     },
 )
 _OptionalCreatePipelineRequestRequestTypeDef = TypedDict(
     "_OptionalCreatePipelineRequestRequestTypeDef",
     {
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -732,7 +732,7 @@ DatastorePartitionTypeDef = TypedDict(
 DatastorePartitionsTypeDef = TypedDict(
     "DatastorePartitionsTypeDef",
     {
-        "partitions": List["DatastorePartitionTypeDef"],
+        "partitions": Sequence["DatastorePartitionTypeDef"],
     },
     total=False,
 )
@@ -758,7 +758,7 @@ DatastoreStorageSummaryTypeDef = TypedDict(
 DatastoreStorageTypeDef = TypedDict(
     "DatastoreStorageTypeDef",
     {
-        "serviceManagedS3": Dict[str, Any],
+        "serviceManagedS3": Mapping[str, Any],
         "customerManagedS3": "CustomerManagedDatastoreS3StorageTypeDef",
         "iotSiteWiseMultiLayerStorage": "DatastoreIotSiteWiseMultiLayerStorageTypeDef",
     },
@@ -1020,7 +1020,7 @@ EstimatedResourceSizeTypeDef = TypedDict(
 FileFormatConfigurationTypeDef = TypedDict(
     "FileFormatConfigurationTypeDef",
     {
-        "jsonConfiguration": Dict[str, Any],
+        "jsonConfiguration": Mapping[str, Any],
         "parquetConfiguration": "ParquetConfigurationTypeDef",
     },
     total=False,
@@ -1423,7 +1423,7 @@ _RequiredRemoveAttributesActivityTypeDef = TypedDict(
     "_RequiredRemoveAttributesActivityTypeDef",
     {
         "name": str,
-        "attributes": List[str],
+        "attributes": Sequence[str],
     },
 )
 _OptionalRemoveAttributesActivityTypeDef = TypedDict(
@@ -1483,7 +1483,7 @@ RunPipelineActivityRequestRequestTypeDef = TypedDict(
     "RunPipelineActivityRequestRequestTypeDef",
     {
         "pipelineActivity": "PipelineActivityTypeDef",
-        "payloads": List[Union[bytes, IO[bytes], StreamingBody]],
+        "payloads": Sequence[Union[bytes, IO[bytes], StreamingBody]],
     },
 )
 
@@ -1561,7 +1561,7 @@ ScheduleTypeDef = TypedDict(
 SchemaDefinitionTypeDef = TypedDict(
     "SchemaDefinitionTypeDef",
     {
-        "columns": List["ColumnTypeDef"],
+        "columns": Sequence["ColumnTypeDef"],
     },
     total=False,
 )
@@ -1570,7 +1570,7 @@ _RequiredSelectAttributesActivityTypeDef = TypedDict(
     "_RequiredSelectAttributesActivityTypeDef",
     {
         "name": str,
-        "attributes": List[str],
+        "attributes": Sequence[str],
     },
 )
 _OptionalSelectAttributesActivityTypeDef = TypedDict(
@@ -1597,7 +1597,7 @@ _RequiredSqlQueryDatasetActionTypeDef = TypedDict(
 _OptionalSqlQueryDatasetActionTypeDef = TypedDict(
     "_OptionalSqlQueryDatasetActionTypeDef",
     {
-        "filters": List["QueryFilterTypeDef"],
+        "filters": Sequence["QueryFilterTypeDef"],
     },
     total=False,
 )
@@ -1645,7 +1645,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": List["TagTypeDef"],
+        "tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1689,7 +1689,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
@@ -1719,17 +1719,17 @@ _RequiredUpdateDatasetRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateDatasetRequestRequestTypeDef",
     {
         "datasetName": str,
-        "actions": List["DatasetActionTypeDef"],
+        "actions": Sequence["DatasetActionTypeDef"],
     },
 )
 _OptionalUpdateDatasetRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateDatasetRequestRequestTypeDef",
     {
-        "triggers": List["DatasetTriggerTypeDef"],
-        "contentDeliveryRules": List["DatasetContentDeliveryRuleTypeDef"],
+        "triggers": Sequence["DatasetTriggerTypeDef"],
+        "contentDeliveryRules": Sequence["DatasetContentDeliveryRuleTypeDef"],
         "retentionPeriod": "RetentionPeriodTypeDef",
         "versioningConfiguration": "VersioningConfigurationTypeDef",
-        "lateDataRules": List["LateDataRuleTypeDef"],
+        "lateDataRules": Sequence["LateDataRuleTypeDef"],
     },
     total=False,
 )
@@ -1768,7 +1768,7 @@ UpdatePipelineRequestRequestTypeDef = TypedDict(
     "UpdatePipelineRequestRequestTypeDef",
     {
         "pipelineName": str,
-        "pipelineActivities": List["PipelineActivityTypeDef"],
+        "pipelineActivities": Sequence["PipelineActivityTypeDef"],
     },
 )
 
